# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

%global pypi_name tox

Name:           python-tox
Version:        4.11.1
Release:        %mkrel 1
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python

# file toxbootstrap.py is licensed under MIT License
License:        GPLv2+ and MIT
URL:            https://pypi.org/project/tox/
Source0:        %{pypi_source}
# Remove dependency on devpi-process.
# Remove dependency on detect-test-pollution.
# Remove coverage-related dependencies.
# Adjust virtualenv environment variables to make it work with our patched virtualenv.
Patch:          fix-tests.patch
BuildArch:      noarch
BuildRequires:  python3-devel

%description
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%package -n python3-%{pypi_name}
Summary:        Virtualenv-based automation of test activities
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:	python3-py
Requires:	python3-pluggy
# python3-virtualenv is rhbz#537246
Requires:	python3-virtualenv

%description -n python3-%{pypi_name}
Tox as is a generic virtualenv management and test command line tool you
can use for:

 - checking your package installs correctly with different Python versions
   and interpreters
 - running your tests in each of the environments, configuring your test tool
   of choice
 - acting as a frontend to Continuous Integration servers, greatly reducing
   boilerplate and merging CI and shell-based testing.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# Upstream updates dependencies too aggressively
# see https://github.com/tox-dev/tox/pull/2843#discussion_r1065028356
sed -ri -e 's/"(packaging|filelock|platformdirs|psutil|diff-cover|pyproject-api|pytest|pytest-mock|pytest-xdist|wheel|pluggy|distlib|cachetools)>=.*/"\1",/g' \
        -e "s/'(time-machine)>=[^;']+/'\1/" \
        -e 's/"(virtualenv)>=.*/"\1>=20",/g' \
        -e 's/"(hatchling)>=.*/"\1>=1.13",/g' \
    pyproject.toml

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_buildrequires

%build
export SETUPTOOLS_SCM_PRETEND_VERSION="%{version}"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

# if internet connection available, run tests
%if %{with internet}
%check
%tox
%endif

%files -n python3-tox -f %{pyproject_files}
%license LICENSE
%{_bindir}/%{pypi_name}


%changelog
* Wed Dec 20 2023 tv <tv> 4.11.1-1.mga10
+ Revision: 2020416
- 4.11.1

* Thu Dec 07 2023 wally <wally> 3.27.1-2.mga10
+ Revision: 2015165
- rebuild for py3.12
- use %%pyproject_buildrequires

* Fri Nov 18 2022 kekepower <kekepower> 3.27.1-1.mga9
+ Revision: 1908716
- Rediff Patch0
- Update to version 3.27.1

* Tue Sep 06 2022 wally <wally> 3.25.1-1.mga9
+ Revision: 1884498
- new version 3.25.1
- switch build to use pyproject rpm macros

* Tue Mar 29 2022 umeabot <umeabot> 3.23.0-4.mga9
+ Revision: 1832164
- Mageia 9 Mass Rebuild

* Sat Feb 12 2022 tv <tv> 3.23.0-3.mga9
+ Revision: 1773469
- Rebuild for python-3.10

* Mon Mar 15 2021 neoclust <neoclust> 3.23.0-2.mga9
+ Revision: 1703221
- Rebuild against python 3.9

* Wed Mar 03 2021 guillomovitch <guillomovitch> 3.23.0-1.mga9
+ Revision: 1697489
- new version 3.23.0
- fix automatic dependencies

* Mon Mar 01 2021 guillomovitch <guillomovitch> 3.22.0-1.mga9
+ Revision: 1695272
- new version 3.22.0

* Sun Mar 29 2020 wally <wally> 3.14.6-1.mga8
+ Revision: 1562172
- new version 3.14.6

* Sun Feb 16 2020 umeabot <umeabot> 3.14.0-2.mga8
+ Revision: 1530981
- Mageia 8 Mass Rebuild

* Sat Sep 07 2019 wally <wally> 3.14.0-1.mga8
+ Revision: 1438147
- new version 3.14.0
- drop python2 support
- rebuild for python3.8

* Sat Apr 20 2019 wally <wally> 3.9.0-1.mga7
+ Revision: 1393916
- new version 3.9.0

* Mon Jan 07 2019 wally <wally> 3.0.0-0.rc1.3.mga7
+ Revision: 1350664
- rebuild for python3.7

* Fri Sep 21 2018 umeabot <umeabot> 3.0.0-0.rc1.2.mga7
+ Revision: 1290431
- Mageia 7 Mass Rebuild

* Tue Feb 06 2018 guillomovitch <guillomovitch> 3.0.0-0.rc1.1.mga7
+ Revision: 1199387
- new version 3.0.0rc1

* Sat Aug 05 2017 pterjan <pterjan> 2.3.1-3.mga7
+ Revision: 1135667
- Rebuild for python 3.6

* Sun May 15 2016 ngompa <ngompa> 2.3.1-2.mga6
+ Revision: 1015696
- imported package python-tox

